==> clash-ghc-1.8.2-47-x86_64.pkg.tar.zst: usr/share/haskell/register/clash-ghc.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 clash-ghc
version:              1.8.2
visibility:           public
id:                   clash-ghc-1.8.2-11Mh59k7UKBBCa5KbHqd2u
key:                  clash-ghc-1.8.2-11Mh59k7UKBBCa5KbHqd2u
license:              BSD-2-Clause
copyright:
    Copyright © 2012-2016, University of Twente,
    2016-2017, Myrtle Software Ltd,
    2017-2019, QBayLogic B.V., Google Inc.

maintainer:           QBayLogic B.V. <devops@qbaylogic.com>
author:               The Clash Authors
homepage:             https://clash-lang.org/
synopsis:
    Clash: a functional hardware description language - GHC frontend

description:
    Clash is a functional hardware description language that borrows both its
    syntax and semantics from the functional programming language Haskell. The
    Clash compiler transforms these high-level descriptions to low-level
    synthesizable VHDL, Verilog, or SystemVerilog.

    Features of Clash:

    * Strongly typed, but with a very high degree of type inference, enabling both
    safe and fast prototyping using concise descriptions.

    * Interactive REPL: load your designs in an interpreter and easily test all
    your component without needing to setup a test bench.

    * Higher-order functions, with type inference, result in designs that are
    fully parametric by default.

    * Synchronous sequential circuit design based on streams of values, called
    @Signal@s, lead to natural descriptions of feedback loops.

    * Support for multiple clock domains, with type safe clock domain crossing.


    This package provides:

    * Clash Compiler binary using GHC/Haskell as a frontend


    Prelude library: <https://hackage.haskell.org/package/clash-prelude>

category:             Hardware
abi:                  d9a2e865cd0e193e0367e4bb57134c91
exposed:              True
exposed-modules:
    Clash.GHC.Evaluator Clash.GHC.Evaluator.Primitive
    Clash.GHC.GenerateBindings Clash.GHC.LoadModules
    Clash.GHC.NetlistTypes Clash.GHC.PartialEval
    Clash.GHC.PartialEval.Eval Clash.GHC.PartialEval.Primitive
    Clash.GHC.PartialEval.Quote Clash.GHCi.Common Clash.Main

hidden-modules:
    Clash.GHCi.Leak Clash.GHCi.UI Clash.GHCi.UI.Info
    Clash.GHCi.UI.Monad Clash.GHC.ClashFlags Clash.GHC.GHC2Core
    Clash.GHC.LoadInterfaceFiles Clash.GHC.Util Data.Text.Extra
    Paths_clash_ghc Clash.GHCi.Util Clash.GHCi.UI.Tags

import-dirs:          /usr/lib/ghc-9.4.8/site-local/clash-ghc-1.8.2
library-dirs:         /usr/lib/ghc-9.4.8/site-local/clash-ghc-1.8.2
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/clash-ghc-1.8.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/clash-ghc
hs-libraries:         HSclash-ghc-1.8.2-11Mh59k7UKBBCa5KbHqd2u
depends:
    Cabal-3.8.1.0 array-0.5.4.0 base-4.17.2.1 bytestring-0.11.5.3
    clash-lib-1.8.2-LQOtc1NKpBp71tqQBejmBa
    clash-prelude-1.8.2-96zGOaEhCwq7CEiQTdELBc containers-0.6.7
    data-binary-ieee754-0.4.4-3K4wyZ8KRa1CgKftL8GYsk deepseq-1.4.8.0
    directory-1.3.7.1 exceptions-0.10.5
    extra-1.7.16-2NFI8foRfl5F586yJkh1o1 filepath-1.4.2.2 ghc-9.4.8
    ghc-bignum-1.3 ghc-boot-9.4.8 ghc-prim-0.9.1
    ghc-typelits-extra-0.4.5-Amx87NT3VI9J8IYUTxXI8S
    ghc-typelits-knownnat-0.7.12-OwUYJIqzK2Jh0TJeWDvnW
    ghc-typelits-natnormalise-0.7.10-93MZ9cDDIjlJqgGIYCYSPd ghci-9.4.8
    hashable-1.4.4.0-Htybuq5UDQvAvffgJDQoKe haskeline-0.8.2
    lens-5.3.1-DW98VpYgL8e3Qofq450fQJ mtl-2.2.2
    primitive-0.9.1.0-C8cd7b9dKvqDzbVOzdbvUJ process-1.6.18.0
    reflection-2.1.9-2PMfSln80DgJkmDac7uMuv
    split-0.2.5-Dujwwofvw7aEFmjRmWhj9Q
    string-interpolate-0.3.4.0-6y9ZSuZdqq3D528ROY9dVd
    template-haskell-2.19.0.0 text-2.0.2 time-1.12.2
    transformers-0.5.6.2 uniplate-1.6.13-LAZKgYJCgkW45UK2d80zah
    unix-2.7.3 unordered-containers-0.2.20-FOY8P5Y3sqjANbVUEJi9Vi
    utf8-string-1.0.2-D0oARDqSiCF3CIA0pPBIDm
    vector-0.13.2.0-6oLw41loWTIuQEg8iaHmr

haddock-interfaces:   /usr/share/doc/clash-ghc/html/clash-ghc.haddock
haddock-html:         /usr/share/doc/clash-ghc/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> clash-ghc-1.8.2-48-x86_64.pkg.tar.zst: usr/share/haskell/register/clash-ghc.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 clash-ghc
version:              1.8.2
visibility:           public
id:                   clash-ghc-1.8.2-AVDIk9BU4Pk5VW5RB73gLc
key:                  clash-ghc-1.8.2-AVDIk9BU4Pk5VW5RB73gLc
license:              BSD-2-Clause
copyright:
    Copyright © 2012-2016, University of Twente,
    2016-2017, Myrtle Software Ltd,
    2017-2019, QBayLogic B.V., Google Inc.

maintainer:           QBayLogic B.V. <devops@qbaylogic.com>
author:               The Clash Authors
homepage:             https://clash-lang.org/
synopsis:
    Clash: a functional hardware description language - GHC frontend

description:
    Clash is a functional hardware description language that borrows both its
    syntax and semantics from the functional programming language Haskell. The
    Clash compiler transforms these high-level descriptions to low-level
    synthesizable VHDL, Verilog, or SystemVerilog.

    Features of Clash:

    * Strongly typed, but with a very high degree of type inference, enabling both
    safe and fast prototyping using concise descriptions.

    * Interactive REPL: load your designs in an interpreter and easily test all
    your component without needing to setup a test bench.

    * Higher-order functions, with type inference, result in designs that are
    fully parametric by default.

    * Synchronous sequential circuit design based on streams of values, called
    @Signal@s, lead to natural descriptions of feedback loops.

    * Support for multiple clock domains, with type safe clock domain crossing.


    This package provides:

    * Clash Compiler binary using GHC/Haskell as a frontend


    Prelude library: <https://hackage.haskell.org/package/clash-prelude>

category:             Hardware
abi:                  97a6114e0e40939849b86e150cd9d18a
exposed:              True
exposed-modules:
    Clash.GHC.Evaluator Clash.GHC.Evaluator.Primitive
    Clash.GHC.GenerateBindings Clash.GHC.LoadModules
    Clash.GHC.NetlistTypes Clash.GHC.PartialEval
    Clash.GHC.PartialEval.Eval Clash.GHC.PartialEval.Primitive
    Clash.GHC.PartialEval.Quote Clash.GHCi.Common Clash.Main

hidden-modules:
    Clash.GHCi.Leak Clash.GHCi.UI Clash.GHCi.UI.Info
    Clash.GHCi.UI.Monad Clash.GHC.ClashFlags Clash.GHC.GHC2Core
    Clash.GHC.LoadInterfaceFiles Clash.GHC.Util Data.Text.Extra
    Paths_clash_ghc Clash.GHCi.Util Clash.GHCi.UI.Tags

import-dirs:          /usr/lib/ghc-9.4.8/site-local/clash-ghc-1.8.2
library-dirs:         /usr/lib/ghc-9.4.8/site-local/clash-ghc-1.8.2
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/clash-ghc-1.8.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/clash-ghc
hs-libraries:         HSclash-ghc-1.8.2-AVDIk9BU4Pk5VW5RB73gLc
depends:
    Cabal-3.8.1.0 array-0.5.4.0 base-4.17.2.1 bytestring-0.11.5.3
    clash-lib-1.8.2-HSMVKlREuCMxSQwNRgCoF
    clash-prelude-1.8.2-9ypFM6fim39KgiWOldjucM containers-0.6.7
    data-binary-ieee754-0.4.4-3K4wyZ8KRa1CgKftL8GYsk deepseq-1.4.8.0
    directory-1.3.7.1 exceptions-0.10.5
    extra-1.7.16-I47Rfrva8J15uJNg6ub4mo filepath-1.4.2.2 ghc-9.4.8
    ghc-bignum-1.3 ghc-boot-9.4.8 ghc-prim-0.9.1
    ghc-typelits-extra-0.4.5-LwjvfyUWf3oLYEOozG1Ij
    ghc-typelits-knownnat-0.7.12-3RkY211yUJx71RAro9czbQ
    ghc-typelits-natnormalise-0.7.10-BhOhzIwGdlV6S2RoknvSVR ghci-9.4.8
    hashable-1.4.4.0-L4Cy5OzOiFo7EDda82f1f2 haskeline-0.8.2
    lens-5.3.1-7KUGOKnL0sFAtVCcawlRvA mtl-2.2.2
    primitive-0.9.1.0-D2Xl5aBZhziHIyHGKnXxcR process-1.6.18.0
    reflection-2.1.9-HFjyowQfNeeFBpNkAEWJvy
    split-0.2.5-Dujwwofvw7aEFmjRmWhj9Q
    string-interpolate-0.3.4.0-Je4qaDakwsN12gH7qpUaIV
    template-haskell-2.19.0.0 text-2.0.2 time-1.12.2
    transformers-0.5.6.2 uniplate-1.6.13-8J5ONS3ZReH2Ok6GFPFW3M
    unix-2.7.3 unordered-containers-0.2.20-6WajAJaPEOH3f3auRxdjt7
    utf8-string-1.0.2-D0oARDqSiCF3CIA0pPBIDm
    vector-0.13.2.0-ESntcdl2teUG0zU6GNugJH

haddock-interfaces:   /usr/share/doc/clash-ghc/html/clash-ghc.haddock
haddock-html:         /usr/share/doc/clash-ghc/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
